@@ -47,117 +47,121 @@
 #include <sbkpython.h>
 #include <sbkconverter.h>
 // Binded library includes
-#include <qmessageauthenticationcode.h>
-#include <qfiledevice.h>
-#include <qfileinfo.h>
-#include <qbytearray.h>
-#include <qiodevice.h>
-#include <qsystemsemaphore.h>
-#include <qabstractnativeeventfilter.h>
+#include <QtCore/qurl.h>
+#include <QtCore/qjsonvalue.h>
+#include <QtCore/qelapsedtimer.h>
+#include <QtCore/qsemaphore.h>
 #include <qcborvalue.h>
-#include <qwaitcondition.h>
-#include <qregularexpression.h>
-#include <qversionnumber.h>
-#include <qpoint.h>
-#include <qjsonarray.h>
-#include <qlogging.h>
-#include <qdatetime.h>
-#include <qsignaltransition.h>
-#include <qthread.h>
-#include <qtimer.h>
-#include <qparallelanimationgroup.h>
+#include <QtCore/qmessageauthenticationcode.h>
+#include <QtCore/qobject.h>
+#include <QtCore/qthreadpool.h>
+#include <QtCore/qtimer.h>
+#include <QtCore/qlocale.h>
+#include <QtCore/qabstractitemmodel.h>
+#include <QtCore/qmimedatabase.h>
+#include <QtCore/qabstractnativeeventfilter.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qabstractanimation.h>
+#include <QtCore/qcborarray.h>
+#include <QtCore/qpoint.h>
+#include <QtCore/qsize.h>
+#include <QtCore/qhistorystate.h>
+#include <QtCore/qpauseanimation.h>
+#include <QtCore/qsignalmapper.h>
+#include <QtCore/qfilesystemwatcher.h>
+#include <QtCore/qtemporarydir.h>
+#include <QtCore/qabstractstate.h>
 #include <qcborcommon.h>
-#include <qtextboundaryfinder.h>
-#include <qcommandlineparser.h>
-#include <qrandom.h>
+#include <QtCore/qvariantanimation.h>
+#include <QtCore/qmetaobject.h>
+#include <QtCore/qsavefile.h>
+#include <QtCore/qcbormap.h>
+#include <QtCore/qsortfilterproxymodel.h>
+#include <QtCore/qtextboundaryfinder.h>
+#include <QtCore/qabstracteventdispatcher.h>
+#include <QtCore/qfiledevice.h>
+#include <QtCore/qline.h>
+#include <QtCore/qurlquery.h>
+#include <QtCore/qnamespace.h>
 #include <QtCore/qbuffer.h>
-#include <qpropertyanimation.h>
-#include <qrunnable.h>
-#include <qtextcodec.h>
-#include <qfactoryinterface.h>
-#include <qlockfile.h>
-#include <qeventloop.h>
-#include <qstatemachine.h>
-#include <qreadwritelock.h>
-#include <qmutex.h>
-#include <qmimedata.h>
-#include <qcbormap.h>
-#include <qdiriterator.h>
-#include <qsize.h>
-#include <qdatastream.h>
-#include <qresource.h>
-#include <qabstracttransition.h>
-#include <qbytearraymatcher.h>
-#include <qanimationgroup.h>
-#include <qcollator.h>
-#include <qpluginloader.h>
-#include <qlibraryinfo.h>
+#include <QtCore/qbitarray.h>
+#include <QtCore/qmutex.h>
+#include <QtCore/qthread.h>
+#include <QtCore/qwaitcondition.h>
+#include <QtCore/qversionnumber.h>
+#include <QtCore/qtimeline.h>
+#include <QtCore/qxmlstream.h>
+#include <QtCore/qcommandlineoption.h>
+#include <QtCore/qcborcommon.h>
+#include <QtCore/qrandom.h>
+#include <QtCore/qsequentialanimationgroup.h>
+#include <QtCore/qprocess.h>
+#include <QtCore/quuid.h>
+#include <QtCore/qrect.h>
+#include <QtCore/qoperatingsystemversion.h>
+#include <QtCore/qabstracttransition.h>
+#include <QtCore/qmimetype.h>
 #include <qobjectdefs.h>
-#include <qline.h>
-#include <qcoreapplication.h>
-#include <qjsonvalue.h>
-#include <qfinalstate.h>
-#include <qtimezone.h>
-#include <qabstractproxymodel.h>
-#include <qtemporaryfile.h>
-#include <qprocess.h>
-#include <qcryptographichash.h>
-#include <qitemselectionmodel.h>
-#include <qcborarray.h>
+#include <QtCore/qmargins.h>
+#include <QtCore/qregularexpression.h>
+#include <QtCore/qlibraryinfo.h>
+#include <QtCore/qsettings.h>
+#include <QtCore/qdatetime.h>
+#include <QtCore/qabstractproxymodel.h>
+#include <QtCore/qcoreapplication.h>
+#include <QtCore/qcommandlineparser.h>
+#include <QtCore/qdiriterator.h>
+#include <QtCore/qreadwritelock.h>
+#include <QtCore/qfileinfo.h>
 #include <qcborstream.h>
-#include <qstorageinfo.h>
-#include <qtranslator.h>
-#include <qsocketnotifier.h>
-#include <qjsondocument.h>
-#include <qsemaphore.h>
-#include <qtextstream.h>
-#include <qurl.h>
-#include <qsortfilterproxymodel.h>
-#include <qstandardpaths.h>
-#include <qmargins.h>
-#include <quuid.h>
-#include <qvariantanimation.h>
-#include <qabstractitemmodel.h>
-#include <qstringlistmodel.h>
-#include <qdir.h>
-#include <qnamespace.h>
-#include <qrect.h>
-#include <qsequentialanimationgroup.h>
-#include <qeventtransition.h>
-#include <qurlquery.h>
-#include <qbitarray.h>
-#include <qabstracteventdispatcher.h>
-#include <qeasingcurve.h>
-#include <qxmlstream.h>
-#include <qelapsedtimer.h>
-#include <qabstractanimation.h>
-#include <qsavefile.h>
+#include <QtCore/qcoreevent.h>
+#include <QtCore/qpropertyanimation.h>
+#include <QtCore/qfile.h>
+#include <QtCore/qiodevice.h>
+#include <QtCore/qitemselectionmodel.h>
+#include <QtCore/qstatemachine.h>
+#include <QtCore/qparallelanimationgroup.h>
+#include <QtCore/qbytearray.h>
+#include <QtCore/qanimationgroup.h>
+#include <QtCore/qcborvalue.h>
+#include <QtCore/qobjectdefs.h>
+#include <QtCore/qstringlistmodel.h>
+#include <QtCore/qsysinfo.h>
+#include <QtCore/qstorageinfo.h>
+#include <QtCore/qeventtransition.h>
+#include <QtCore/qjsonarray.h>
+#include <QtCore/qsignaltransition.h>
+#include <QtCore/qdatastream.h>
+#include <QtCore/qlockfile.h>
+#include <QtCore/qpluginloader.h>
+#include <QtCore/qcborstream.h>
+#include <QtCore/qtemporaryfile.h>
+#include <QtCore/qsocketnotifier.h>
+#include <QtCore/qfinalstate.h>
+#include <QtCore/qrunnable.h>
+#include <QtCore/qtextstream.h>
 #include <QList>
-#include <qfileselector.h>
-#include <qbasictimer.h>
-#include <qfile.h>
-#include <qfilesystemwatcher.h>
+#include <QtCore/qfactoryinterface.h>
+#include <QtCore/qstate.h>
+#include <QtCore/qeasingcurve.h>
+#include <QtCore/qtextcodec.h>
+#include <QtCore/qeventloop.h>
+#include <QtCore/qstandardpaths.h>
 #include <QTextCodec>
-#include <qhistorystate.h>
-#include <qsignalmapper.h>
-#include <qstate.h>
-#include <qsysinfo.h>
-#include <qtemporarydir.h>
-#include <qregexp.h>
-#include <qthreadpool.h>
-#include <qtimeline.h>
-#include <qmimedatabase.h>
-#include <qmimetype.h>
-#include <qidentityproxymodel.h>
-#include <qobject.h>
-#include <qabstractstate.h>
-#include <qlocale.h>
-#include <qpauseanimation.h>
-#include <qsettings.h>
-#include <qcoreevent.h>
-#include <qcommandlineoption.h>
-#include <qoperatingsystemversion.h>
-#include <qmetaobject.h>
+#include <QtCore/qtranslator.h>
+#include <QtCore/qcryptographichash.h>
+#include <QtCore/qmimedata.h>
+#include <QtCore/qjsondocument.h>
+#include <QtCore/qregexp.h>
+#include <QtCore/qresource.h>
+#include <QtCore/qlogging.h>
+#include <QtCore/qbytearraymatcher.h>
+#include <QtCore/qcollator.h>
+#include <QtCore/qidentityproxymodel.h>
+#include <QtCore/qfileselector.h>
+#include <QtCore/qbasictimer.h>
+#include <QtCore/qsystemsemaphore.h>
+#include <QtCore/qtimezone.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -476,7 +480,7 @@ enum : int {
     SBK_QXMLSTREAMREADER_READELEMENTTEXTBEHAVIOUR_IDX        = 312,
     SBK_QXMLSTREAMREADER_ERROR_IDX                           = 311,
     SBK_QXMLSTREAMWRITER_IDX                                 = 314,
-    SBK_QT_IDX                                               = 315,
+    SBK_QtCoreQT_IDX                                         = 315,
     SBK_QT_GLOBALCOLOR_IDX                                   = 349,
     SBK_QT_KEYBOARDMODIFIER_IDX                              = 359,
     SBK_QFLAGS_QT_KEYBOARDMODIFIER_IDX                       = 122,
